using System;
using System.Collections;
using System.IO;

using GBPVR.Backend.Common;
using GBPVR.Public;

namespace DetectMultiRecordings
{
	/// <summary>
	/// Summary description for DetectMultiRecordings.
	/// </summary>
	class DetectMultiRecordings
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			if (args.Length == 0) 
			{
				Console.WriteLine("args.Length == 0");
				return;
			}
			
			string fullPath = args[0];

			Console.WriteLine("Processing: {0}", fullPath);

			string path = Path.GetDirectoryName(fullPath);
			string fileName = Path.GetFileNameWithoutExtension(fullPath);
			string extension = Path.GetExtension(fullPath);

			int recordingChunkNumber = 0;
			int knownChunks = 0;

			IScheduleHelper scheduleHelper = ScheduleHelper.getInstance();
			ScheduledRecording recording = null;

			IList myScheduledRecordings = scheduleHelper.LoadRecordingSchedule();
			foreach (ScheduledRecording scheduledRecording in myScheduledRecordings)
			{
				if (string.Compare(scheduledRecording.getFileName(), fullPath, true) == 0)
				{
					recording = scheduledRecording;
				}
				if (Path.GetFileNameWithoutExtension(scheduledRecording.getFileName()).ToLower().StartsWith(fileName.ToLower())) 
				{
					knownChunks++;
				}
			}

			if (knownChunks == 0) 
			{
				Console.WriteLine("knownChunks = 0");
				return;
			}
			if (knownChunks > 1) 
			{
				Console.WriteLine("knownChunks > 1");
				return;
			}
			if (recording == null) 
			{
				Console.WriteLine("recording == null");
				return;
			}

			DateTime endTime = recording.getEndTime();
			int postPadMinutes = recording.getPostPadMinutes();

			while (true)
			{
				recordingChunkNumber++;
				string newPath = Path.Combine(path, fileName) + "-" + recordingChunkNumber.ToString() + extension;

				if (File.Exists(newPath)) 
				{
					recording.setEndTime(File.GetLastWriteTime(fullPath));
					recording.setPostPadMinutes(0);
					scheduleHelper.UpdateScheduledRecording(recording);

					ScheduledRecording newrecording = new ScheduledRecording();
					Programme programme = recording.getProgramme();
					newrecording.setProgrammme(programme);
					object captureSource = recording.getCaptureSource();
					newrecording.setCaptureSource(captureSource);
					newrecording.setFileName(newPath);
					newrecording.setRecordingStatus(recording.getRecordingStatus());
					newrecording.setRecordingGroup(recording.getRecordingGroup());
					newrecording.setRecordingType(recording.getRecordingType());
					newrecording.setChannelOID(recording.getChannelOID());
					newrecording.setStartTime(recording.getEndTime());
					newrecording.setQualitySetting(recording.getQualitySetting());
					newrecording.setPrePadMinutes(0);

					recording = newrecording;
					fullPath = newPath;
				}
				else
				{
					break;
				}
			}

			if (recordingChunkNumber > 1) 
			{
				recording.setEndTime(endTime);
				recording.setPostPadMinutes(postPadMinutes);
				scheduleHelper.UpdateScheduledRecording(recording);
			}
		}
	}
}
